@@ -2,12 +2,16 @@ package t::lib::Test;
 
 use strict;
 use Exporter   ();
+use File::Spec ();
 use Test::More ();
 
 use vars qw{@ISA @EXPORT};
 BEGIN {
 	@ISA    = qw{ Exporter };
-	@EXPORT = qw{ tests  yaml_ok  yaml_error slurp  load_ok };
+	@EXPORT = qw{
+		tests  yaml_ok  yaml_error slurp  load_ok
+		test_data_directory
+	};
 }
 
 # Do we have the authorative YAML to test against
@@ -64,6 +68,10 @@ sub tests {
 	return ( tests => count(@_) );
 }
 
+sub test_data_directory {
+	return File::Spec->catdir( 't', 'data' );
+}
+
 sub count {
 	my $yaml_ok = shift || 0;
 	my $load_ok = shift || 0;
@@ -267,7 +275,7 @@ sub yaml_ok {
 sub yaml_error {
 	my $string = shift;
 	my $yaml   = eval { YAML::Tiny->read_string( $string ); };
-	Test::More::like( $@, qr/$_[0]/, "YAML::Tiny throws expected error" );
+	Test::More::ok( $@ =~ /$_[0]/, "TAML::Tiny throws expected error" );
 }
 
 sub slurp {
